@@ -15,7 +15,15 @@ from sklearn.base import BaseEstimator
 class GTMBase(BaseEstimator):
     """
     The original Generative Topographic Mapping (GTM) model by Bishop et al. 1998
-    Implemented with reference of GTM toolbox by Lain Strachan written in Matlab
+    Implemented with reference of GTM toolbox by Lain Strachan written in Matlab.
+
+    :param s: Scale factor of sigma
+    :param l: Regulatory factor. Larger l can prevent singularity during training but
+        decrease the model performance and may cause unexpected error.
+
+    :param map_shape: The shape of latent space grid.
+    :param rbf_shape: The shape of radial basis function grid.
+    :param pca: Flag for using PCA to initialize weights W.
     """
     def __init__(self, s=2, l=0.001, map_shape=(16, 16), rbf_shape=(5, 5), pca=True):
         # hyper parameters
@@ -131,13 +139,6 @@ class GTMBase(BaseEstimator):
 
         return llh
 
-    def calibrate(self):
-        """ calibrate the R matrix after last optimize """
-        dist = cdist(self.T, self.phi_with_ones.dot(self.W), metric='sqeuclidean')
-        exp_term: np.ndarray = np.exp((-self.beta / 2) * dist)
-        exp_term_sum_over_k = exp_term.sum(axis=1)
-        self.R: np.ndarray = (exp_term / exp_term_sum_over_k.reshape(-1, 1)).T
-
     def fit(self, x, y=None, epoch=10, early_stopping=False, tol=10):
         """
         train the model. y will not be used.
@@ -155,6 +156,13 @@ class GTMBase(BaseEstimator):
             print(f"{epoch}: {llh}")
         print("Done")
 
+    def calibrate(self):
+        """ calibrate the R matrix after last optimize """
+        dist = cdist(self.T, self.phi_with_ones.dot(self.W), metric='sqeuclidean')
+        exp_term: np.ndarray = np.exp((-self.beta / 2) * dist)
+        exp_term_sum_over_k = exp_term.sum(axis=1)
+        self.R: np.ndarray = (exp_term / exp_term_sum_over_k.reshape(-1, 1)).T
+
     def plot_llh(self):
         """Plot the training log-likelihood figure"""
         plt.plot(self.llhs)
