@@ -4,19 +4,18 @@ import random
 
 import numpy as np
 from scipy.spatial.distance import cdist
-from gtm_base import GTMBase
+from .gtm_base import GTMBase
 
 import matplotlib.pyplot as plt
 import pandas as pd
 
-from bokeh_app import run_server
+from .bokeh_app import run_server
 
 from sklearn.base import BaseEstimator
 
 
 class GTMTimeSeries(GTMBase, BaseEstimator):
     """GTM model for time series or sequential data """
-    #todo: write document for the module
 
     def __init__(self, s=2, group_size=5, l=0.01,
                  map_shape: tuple = (10, 10), rbf_shape: tuple = (4, 4)):
@@ -323,8 +322,8 @@ class GTMTimeSeries(GTMBase, BaseEstimator):
 
     def single_sequence_opt(self, obs: np.ndarray):
         """
-        Steps:
-        for each sequence (length, d) in the training series sets (num_obs, length, d)
+        Steps::
+
             1. calc DIST and B
             2. forward-backward
             3. gamma
